==> huaweicloudsdkvpc-3.1.92-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/remove_security_groups_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveSecurityGroupsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'request_id': 'str',
        'port': 'Port'
    }

    attribute_map = {
        'request_id': 'request_id',
        'port': 'port'
    }

    def __init__(self, request_id=None, port=None):
        """RemoveSecurityGroupsResponse

        The model defined in huaweicloud sdk

        :param request_id: 请求ID
        :type request_id: str
        :param port: 
        :type port: :class:`huaweicloudsdkvpc.v3.Port`
        """
        
        super(RemoveSecurityGroupsResponse, self).__init__()

        self._request_id = None
        self._port = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if port is not None:
            self.port = port

    @property
    def request_id(self):
        """Gets the request_id of this RemoveSecurityGroupsResponse.

        请求ID

        :return: The request_id of this RemoveSecurityGroupsResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this RemoveSecurityGroupsResponse.

        请求ID

        :param request_id: The request_id of this RemoveSecurityGroupsResponse.
        :type request_id: str
        """
        self._request_id = request_id

    @property
    def port(self):
        """Gets the port of this RemoveSecurityGroupsResponse.

        :return: The port of this RemoveSecurityGroupsResponse.
        :rtype: :class:`huaweicloudsdkvpc.v3.Port`
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this RemoveSecurityGroupsResponse.

        :param port: The port of this RemoveSecurityGroupsResponse.
        :type port: :class:`huaweicloudsdkvpc.v3.Port`
        """
        self._port = port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveSecurityGroupsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/remove_security_groups_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveSecurityGroupsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'request_id': 'str',
        'port': 'Port'
    }

    attribute_map = {
        'request_id': 'request_id',
        'port': 'port'
    }

    def __init__(self, request_id=None, port=None):
        r"""RemoveSecurityGroupsResponse

        The model defined in huaweicloud sdk

        :param request_id: 请求ID
        :type request_id: str
        :param port: 
        :type port: :class:`huaweicloudsdkvpc.v3.Port`
        """
        
        super(RemoveSecurityGroupsResponse, self).__init__()

        self._request_id = None
        self._port = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if port is not None:
            self.port = port

    @property
    def request_id(self):
        r"""Gets the request_id of this RemoveSecurityGroupsResponse.

        请求ID

        :return: The request_id of this RemoveSecurityGroupsResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        r"""Sets the request_id of this RemoveSecurityGroupsResponse.

        请求ID

        :param request_id: The request_id of this RemoveSecurityGroupsResponse.
        :type request_id: str
        """
        self._request_id = request_id

    @property
    def port(self):
        r"""Gets the port of this RemoveSecurityGroupsResponse.

        :return: The port of this RemoveSecurityGroupsResponse.
        :rtype: :class:`huaweicloudsdkvpc.v3.Port`
        """
        return self._port

    @port.setter
    def port(self, port):
        r"""Sets the port of this RemoveSecurityGroupsResponse.

        :param port: The port of this RemoveSecurityGroupsResponse.
        :type port: :class:`huaweicloudsdkvpc.v3.Port`
        """
        self._port = port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveSecurityGroupsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
